@@ -99,25 +99,47 @@ public class Utils {
    */
   static List<String> splitSqlStatement(String sql) {
     List<String> parts = new ArrayList<>();
-    int apCount = 0;
+    boolean inSingleQuote = false;
+    boolean inDoubleQuote = false;
+    boolean inComment = false;
     int off = 0;
     boolean skip = false;
 
     for (int i = 0; i < sql.length(); i++) {
       char c = sql.charAt(i);
+      if (inComment) {
+        inComment = (c != '\n');
+        continue;
+      }
       if (skip) {
         skip = false;
         continue;
       }
       switch (c) {
         case '\'':
-          apCount++;
+          if (!inDoubleQuote) {
+            inSingleQuote = !inSingleQuote;
+          }
+          break;
+        case '\"':
+          if (!inSingleQuote) {
+            inDoubleQuote = !inDoubleQuote;
+          }
+          break;
+        case '-':
+          if (!inSingleQuote && !inDoubleQuote) {
+            if (i < sql.length() - 1 && sql.charAt(i + 1) == '-') {
+              inComment = true;
+            }
+          }
           break;
         case '\\':
-          skip = true;
+          if (!inSingleQuote && !inDoubleQuote) {
+            skip = true;
+          }
           break;
         case '?':
-          if ((apCount & 1) == 0) {
+          if (!inSingleQuote && !inDoubleQuote) {
             parts.add(sql.substring(off, i));
             off = i + 1;
           }
