@@ -24,7 +24,7 @@ import org.eclipse.jetty.util.thread.{QueuedThreadPool, ScheduledExecutorSchedul
 
 import org.apache.kyuubi.Utils.isWindows
 
-private[kyuubi] case class JettyServer(
+private[kyuubi] class JettyServer(
     server: Server,
     connector: ServerConnector,
     rootHandler: ContextHandlerCollection) {
@@ -68,16 +68,22 @@ private[kyuubi] case class JettyServer(
     addHandler(JettyUtils.createRedirectHandler(src, dest))
   }
 
-  def getState: String = server.getState
+  def isStarted: Boolean = server.isStarted
 }
 
 object JettyServer {
 
-  def apply(name: String, host: String, port: Int, poolSize: Int): JettyServer = {
+  def apply(
+      name: String,
+      host: String,
+      port: Int,
+      poolSize: Int,
+      stopTimeout: Long): JettyServer = {
     val pool = new QueuedThreadPool(poolSize)
     pool.setName(name)
     pool.setDaemon(true)
     val server = new Server(pool)
+    server.setStopTimeout(stopTimeout)
 
     val errorHandler = new ErrorHandler()
     errorHandler.setShowStacks(true)
