@@ -94,6 +94,10 @@ class KyuubiBatchSession(
     }
   }
 
+  optimizedConf.foreach {
+    case (key, value) => sessionConf.set(key, value)
+  }
+
   override lazy val name: Option[String] =
     batchName.filterNot(_.trim.isEmpty).orElse(optimizedConf.get(KyuubiConf.SESSION_NAME.key))
 
@@ -141,7 +145,7 @@ class KyuubiBatchSession(
       batchType,
       optimizedConf,
       sessionManager.getConf)
-    if (resource != SparkProcessBuilder.INTERNAL_RESOURCE && !isResourceUploaded) {
+    if (resource != SparkProcessBuilder.INTERNAL_RESOURCE) {
       KyuubiApplicationManager.checkApplicationAccessPath(resource, sessionManager.getConf)
     }
   }
