@@ -20,8 +20,8 @@ import router from '@/router'
 import { store } from '@/pinia'
 import i18n from '@/locales'
 import ElementPlus from 'element-plus'
-import '@/styles/element/index.scss'
-import './styles/index.scss'
+import '@/assets/styles/element/index.scss'
+import '@/assets/styles/index.scss'
 import App from './App.vue'
 import * as ElementPlusIconsVue from '@element-plus/icons-vue'
 
